Module: OpenCV
- Defined in:
- ext/opencv.cpp,
lib/version.rb,
ext/opencv.cpp
Overview
=What is OpenCV?
OpenCV is "Open Source Computer Vision Library". OpenCV is developed by Intel and many opensource developers. This library include many useful function for computer vision, such as object-detection.
OpenCV is developed at sourceforge.net
=What is Ruby/OpenCV? Ruby/OpenCV is manual Wrapper of OpenCV (not use SWIG). This library seem to be Ruby.
- object-oriented
- support Garbage Collection by Ruby Ruby/OpenCV is developed http://rubyforge.org/projects/opencv (Official) and http://blueruby.mydns.jp/pages/opencv (Japanese)
=How to install
Show INSTALL
=How to generate this documentation? This document created by rdoc. If you have Ruby 1.8 or later, you might use rdoc command. for example
cd opencv rdoc and show "./doc/index.html"
Defined Under Namespace
Modules: CvError, GUI Classes: Curve, CvAvgComp, CvBox2D, CvCapture, CvChain, CvChainCode, CvCircle32f, CvClice, CvConnectedComp, CvContour, CvContourTree, CvConvexityDefect, CvFont, CvHaarClassifierCascade, CvHistogram, CvMat, CvMemStorage, CvMoments, CvPoint, CvPoint2D32f, CvPoint3D32f, CvRect, CvScalar, CvSeq, CvSet, CvSize, CvSize2D32f, CvTermCriteria, CvTwopoints, CvVector, CvVideoWriter, IplConvKernel, IplImage
Constant Summary collapse
- VERSION =
'0.0.7'- CV_8U =
8bit unsigned
0- CV_8S =
8bit signed
1- CV_16U =
16bit unsigned
2- CV_16S =
16bit signed
3- CV_32S =
32bit signed
4- CV_32F =
32bit floating-point
5- CV_64F =
64bit floating-point
6- INVERSION_METHOD =
lu, :svd, :svd_sym(:svd_symmetric)}: Inversion method
{- DXT_FLAG =
forward, :inverse, :scale, :rows}: DFT and DCT flags
{- INTERPOLATION_METHOD =
nn, :linear, :area, :cubic}: Interpolation method
{- WARP_FLAG =
fill_outliers, :inverse_map}: Warp affine optional flags
{- DEPTH =
cv8u, :cv8s, :cv16u, :cv16s, :cv32s, :cv32f, :cv64f}: Depth of each pixel.
{- CONNECTIVITY =
aa(:anti_alias)}: Determined by the closeness of pixel values
{- RETRIEVAL_MODE =
external, :list, :ccomp, :tree}: Retrieval mode
{- APPROX_CHAIN_METHOD =
code, :approx_none, :approx_simple, :apporx_tc89_11, :approx_tc89_kcos}: Approximation method
{- APPROX_POLY_METHOD =
dp}: Approximation method (polygon)
{- MATCH_TEMPLATE_METHOD =
sqdiff, :sqdiff_normed, :ccorr, :ccorr_normed, :ccoeff, :ccoeff_normed}: Match template method
{- LOG_POLAR_METHOD =
log_polar_method
Class Method Summary collapse
- .BayerBG2BGR ⇒ Object
- .BayerBG2RGB ⇒ Object
- .BayerGB2BGR ⇒ Object
- .BayerGB2RGB ⇒ Object
- .BayerGR2BGR ⇒ Object
- .BayerGR2RGB ⇒ Object
- .BayerRG2BGR ⇒ Object
- .BayerRG2RGB ⇒ Object
- .BGR2BGR555 ⇒ Object
- .BGR2BGR565 ⇒ Object
-
.BGR2BGRA ⇒ Object
color convert methods.
- .BGR2GRAY ⇒ Object
- .BGR2HLS ⇒ Object
- .BGR2HSV ⇒ Object
- .BGR2Lab ⇒ Object
- .BGR2Luv ⇒ Object
- .BGR2RGB ⇒ Object
- .BGR2RGBA ⇒ Object
- .BGR2XYZ ⇒ Object
- .BGR2YCrCb ⇒ Object
- .BGR5552BGR ⇒ Object
- .BGR5552BGRA ⇒ Object
- .BGR5552GRAY ⇒ Object
- .BGR5552RGB ⇒ Object
- .BGR5552RGBA ⇒ Object
- .BGR5652BGR ⇒ Object
- .BGR5652BGRA ⇒ Object
- .BGR5652GRAY ⇒ Object
- .BGR5652RGB ⇒ Object
- .BGR5652RGBA ⇒ Object
- .BGRA2BGR ⇒ Object
- .BGRA2BGR555 ⇒ Object
- .BGRA2BGR565 ⇒ Object
- .BGRA2GRAY ⇒ Object
- .BGRA2RGB ⇒ Object
- .BGRA2RGBA ⇒ Object
- .GRAY2BGR ⇒ Object
- .GRAY2BGR555 ⇒ Object
- .GRAY2BGR565 ⇒ Object
- .GRAY2BGRA ⇒ Object
- .GRAY2RGB ⇒ Object
- .GRAY2RGBA ⇒ Object
- .HLS2BGR ⇒ Object
- .HLS2RGB ⇒ Object
- .HSV2BGR ⇒ Object
- .HSV2RGB ⇒ Object
- .Lab2BGR ⇒ Object
- .Lab2RGB ⇒ Object
- .Luv2BGR ⇒ Object
- .Luv2RGB ⇒ Object
- .RGB2BGR ⇒ Object
- .RGB2BGR555 ⇒ Object
- .RGB2BGR565 ⇒ Object
- .RGB2BGRA ⇒ Object
- .RGB2GRAY ⇒ Object
- .RGB2HLS ⇒ Object
- .RGB2HSV ⇒ Object
- .RGB2Lab ⇒ Object
- .RGB2Luv ⇒ Object
- .RGB2RGBA ⇒ Object
- .RGB2XYZ ⇒ Object
- .RGB2YCrCb ⇒ Object
- .RGBA2BGR ⇒ Object
- .RGBA2BGR555 ⇒ Object
- .RGBA2BGR565 ⇒ Object
- .RGBA2BGRA ⇒ Object
- .RGBA2GRAY ⇒ Object
- .RGBA2RGB ⇒ Object
- .XYZ2BGR ⇒ Object
- .XYZ2RGB ⇒ Object
- .YCrCb2BGR ⇒ Object
- .YCrCb2RGB ⇒ Object
Class Method Details
.BayerBG2BGR ⇒ Object
.BayerBG2RGB ⇒ Object
.BayerGB2BGR ⇒ Object
.BayerGB2RGB ⇒ Object
.BayerGR2BGR ⇒ Object
.BayerGR2RGB ⇒ Object
.BayerRG2BGR ⇒ Object
.BayerRG2RGB ⇒ Object
.BGR2BGR555 ⇒ Object
.BGR2BGR565 ⇒ Object
.BGR2BGRA ⇒ Object
color convert methods