Class: OpenCV::CvPoint

Inherits:
Object
  • Object
show all
Defined in:
ext/cvpoint.cpp

Overview

This class means one point on X axis Y axis. X and Y takes the value of the Fixnum. see also CvPoint2D32F

C structure is here, very simple. typdef struct CvPoint{ int x; int y; }