Class: OpenCV::CvPoint3D32f
- Inherits:
-
Object
- Object
- OpenCV::CvPoint3D32f
- Defined in:
- ext/cvpoint3d32f.cpp
Overview
This class means one point on X axis Y axis. X and Y takes the value of the Float. see also CvPoint
C structure is here, very simple. typdef struct CvPoint3D32f{ float x; float y; float z; }