Class: OpenCV::CvSize
- Inherits:
-
Object
- Object
- OpenCV::CvSize
- Defined in:
- ext/cvsize.cpp
Overview
This class means one size on X axis Y axis. X and Y takes the value of the Fixnum.
C structure is here, very simple. typdef struct CvSize{ int width; int height; }