Class: OpenCV::CvSize2D32f

Inherits:
Object
  • Object
show all
Defined in:
ext/cvsize2d32f.cpp

Overview

This class means one size on X axis Y axis. X and Y takes the value of the Float.

C structure is here, very simple. typdef struct CvSize2D32f{ float width; float height; }CvSize2D32f;